lidarwind.data\_attributes.LoadAttributes
=========================================

.. currentmodule:: lidarwind.data_attributes

.. autoclass:: LoadAttributes

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~LoadAttributes.__init__
      ~LoadAttributes.variables_attrs
      ~LoadAttributes.write_coords_attrs
      ~LoadAttributes.write_global_attrs
      ~LoadAttributes.write_variables_attrs
   
   

   
   
   